pub struct AssociatedFunction {
pub variant: Identifier,
pub name: Identifier,
pub arguments: Vec<Expression>,
pub span: Span,
pub id: NodeID,
}Expand description
An access expression to an associated function in a struct, e.g.Pedersen64::hash().
Fields
variant: IdentifierThe inner struct variant.
name: IdentifierThe static struct member function that is being accessed.
arguments: Vec<Expression>The arguments passed to the function name.
span: SpanThe span for the entire expression Foo::bar().
id: NodeIDThe ID of the node.