pub struct Identifier {
pub name: Symbol,
pub span: Span,
pub id: NodeID,
}Expand description
An identifier in a program.
Attention - When adding or removing fields from this struct, please remember to update its Serialize and Deserialize implementation to reflect the new struct instantiation.
Fields
name: SymbolThe symbol that the user wrote, e.g., foo.
span: SpanA span locating where the identifier occurred in the source.
id: NodeIDThe ID of the node.
Implementations