pub struct Location {
pub program: Symbol,
pub path: Vec<Symbol>,
}Fields
program: SymbolThe program name. e.g. credits.aleo or my_library.
path: Vec<Symbol>The absolute path to the item that this Location points to.
Implementations
Sourceimpl Location
impl Location
pub fn new(program: Symbol, path: Vec<Symbol>) -> Location
Sourcepub fn is_dynamic(&self) -> bool
pub fn is_dynamic(&self) -> bool
Check whether this location is the dynamic sentinel.
Sourcepub fn module_path(&self) -> &[Symbol]
pub fn module_path(&self) -> &[Symbol]
The portion of the path above the item, i.e. the module path the item lives in. For program-block items and library top-level items the path has length 1 and this returns an empty slice; for module items it returns the module segments.