pub struct ProgramId {
pub name: Identifier,
pub network: Identifier,
}Expand description
An identifier for a program that is eventually deployed to the network.
Fields
name: IdentifierThe name of the program.
network: IdentifierThe network associated with the program.
Implementations
Sourceimpl ProgramId
impl ProgramId
pub fn span(&self) -> Span
pub fn as_symbol(&self) -> Symbol
Sourcepub fn from_str_with_network(string: &str, network: NetworkName) -> Result<Self>
pub fn from_str_with_network(string: &str, network: NetworkName) -> Result<Self>
Initializes a new ProgramId from a string, using a network parameter to validate using snarkVM.
Sourcepub fn to_address_string(&self, network: NetworkName) -> Result<String>
pub fn to_address_string(&self, network: NetworkName) -> Result<String>
Converts the ProgramId into an address string.