pub enum Expression {
Show 19 variants
ArrayAccess(Box<ArrayAccess>),
Async(AsyncExpression),
Array(ArrayExpression),
Binary(Box<BinaryExpression>),
Intrinsic(Box<IntrinsicExpression>),
Call(Box<CallExpression>),
DynamicOp(Box<DynamicOpExpression>),
Cast(Box<CastExpression>),
Composite(CompositeExpression),
Err(ErrExpression),
Path(Path),
Literal(Literal),
MemberAccess(Box<MemberAccess>),
Repeat(Box<RepeatExpression>),
Ternary(Box<TernaryExpression>),
Tuple(TupleExpression),
TupleAccess(Box<TupleAccess>),
Unary(Box<UnaryExpression>),
Unit(UnitExpression),
}Expand description
Expression that evaluates to a value.
Variants
ArrayAccess(Box<ArrayAccess>)
An array access, e.g. arr[i].
Async(AsyncExpression)
An async block: e.g. async { my_mapping.set(1, 2); }.
Array(ArrayExpression)
An array expression, e.g., [true, false, true, false].
Binary(Box<BinaryExpression>)
A binary expression, e.g., 42 + 24.
Intrinsic(Box<IntrinsicExpression>)
An intrinsic expression, e.g., _my_intrinsic(args).
Call(Box<CallExpression>)
A call expression, e.g., my_fun(args).
DynamicOp(Box<DynamicOpExpression>)
A dynamic operation against an interface, e.g., MyInterface @ (target) :: foobar(args),
MyInterface @ (target) :: counter, or MyInterface @ (target) :: entries.get(i).
Cast(Box<CastExpression>)
A cast expression, e.g., 42u32 as u8.
Composite(CompositeExpression)
An expression of type “error”.
Will result in a compile error eventually.
An expression constructing a composite like Foo { bar: 42, baz }.
Err(ErrExpression)
Path(Path)
A path to some item, e.g., foo::bar::x.
Literal(Literal)
A literal expression.
MemberAccess(Box<MemberAccess>)
An access of a composite member, e.g. composite.member.
Repeat(Box<RepeatExpression>)
An array expression constructed from one repeated element, e.g., [1u32; 5].
Ternary(Box<TernaryExpression>)
A ternary conditional expression cond ? if_expr : else_expr.
Tuple(TupleExpression)
A tuple expression e.g., (foo, 42, true).
TupleAccess(Box<TupleAccess>)
A tuple access expression e.g., foo.2.
Unary(Box<UnaryExpression>)
An unary expression.
Unit(UnitExpression)
A unit expression e.g. ()
Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn as_u32(&self) -> Option<u32>
pub fn as_u32(&self) -> Option<u32>
Returns self as a known u32 if possible. Otherwise, returns a None. This allows for large and/or signed
types but only if they can be safely cast to a u32.
pub fn is_none_expr(&self) -> bool
Sourcepub fn is_pure(&self, get_type: &impl Fn(NodeID) -> Type) -> bool
pub fn is_pure(&self, get_type: &impl Fn(NodeID) -> Type) -> bool
Returns true if we can confidently say evaluating this expression has no side effects, false otherwise
Sourcepub fn zero(
ty: &Type,
span: Span,
node_builder: &NodeBuilder,
composite_lookup: &dyn Fn(&Location) -> Vec<(Symbol, Type)>,
) -> Option<Self>
pub fn zero( ty: &Type, span: Span, node_builder: &NodeBuilder, composite_lookup: &dyn Fn(&Location) -> Vec<(Symbol, Type)>, ) -> Option<Self>
Returns the zero value expression for a given type, if one exists.
This is used during lowering and reconstruction to provide default or
placeholder values (e.g., for get_or_use calls or composite initialization).
Supported types:
- Integers (
i8–i128,u8–u128): literal0 - Boolean: literal
false - Field, Group, Scalar: zero literals
"0" - Composites: recursively constructs a composite with all members zeroed
- Arrays: repeats a zero element for the array length
Returns None if the type has no well-defined zero representation
(e.g. mapping, Future).
The composite_lookup callback provides member definitions for composite types.