pub enum Stub {
FromLeo {
program: Program,
parents: IndexSet<Symbol>,
},
FromAleo {
program: AleoProgram,
parents: IndexSet<Symbol>,
},
FromLibrary {
library: Library,
parents: IndexSet<Symbol>,
},
}Variants
FromLeo
A dependency that is a Leo program.
FromAleo
A dependency that is an Aleo program.
FromLibrary
A dependency that is a Leo library.
Implementations
Sourceimpl Stub
impl Stub
Sourcepub fn explicit_imports(&self) -> Box<dyn Iterator<Item = (Symbol, Span)> + '_>
pub fn explicit_imports(&self) -> Box<dyn Iterator<Item = (Symbol, Span)> + '_>
Returns the programs that this stub imports using explicit imports. Note that library
imports are implicit so they do not show up in this returned iterator.
Sourcepub fn add_parent(&mut self, parent: Symbol)
pub fn add_parent(&mut self, parent: Symbol)
Inserts the given program name as a parent for this stub, implying that the stub is imported by this parent.
Sourcepub fn is_leo_program(&self) -> bool
pub fn is_leo_program(&self) -> bool
Does this Stub represent a Leo program?
Sourcepub fn is_aleo_program(&self) -> bool
pub fn is_aleo_program(&self) -> bool
Does this Stub represent an Aleo program?
Sourcepub fn is_library(&self) -> bool
pub fn is_library(&self) -> bool
Does this Stub represent a library?