pub enum Type {
Show 21 variants
Address,
Array(ArrayType),
Boolean,
Composite(CompositeType),
Field,
Future(FutureType),
Group,
Identifier,
DynRecord,
Ident(Identifier),
Integer(IntegerType),
Mapping(MappingType),
Optional(OptionalType),
Scalar,
Signature,
String,
Tuple(TupleType),
Vector(VectorType),
Numeric,
Unit,
Err,
}Expand description
Explicit type used for defining a variable or expression type
Variants
Address
The address type.
Array(ArrayType)
The array type.
Boolean
The bool type.
Composite(CompositeType)
The composite type.
Field
The field type.
Future(FutureType)
The future type.
Group
The group type.
Identifier
The identifier type.
DynRecord
The dyn record type.
Ident(Identifier)
A reference to a built in type.
Integer(IntegerType)
An integer type.
Mapping(MappingType)
A mapping type.
Optional(OptionalType)
A nullable type.
Scalar
The scalar type.
Signature
The signature type.
String
The string type.
Tuple(TupleType)
A static tuple of at least one type.
Vector(VectorType)
The vector type.
Numeric
Numeric type which should be resolved to Field, Group, Integer(_), or Scalar.
Unit
The unit type.
Err
Placeholder for a type that could not be resolved or was not well-formed. Will eventually lead to a compile error.
Implementations
Sourceimpl Type
impl Type
Sourcepub fn eq_user(&self, other: &Type) -> bool
pub fn eq_user(&self, other: &Type) -> bool
Are the types considered equal as far as the Leo user is concerned?
In particular, any comparison involving an Err is true, and Futures which aren’t explicit compare equal to
other Futures.
An array with an undetermined length (e.g., one that depends on a const) is considered equal to other arrays
if their element types match. This allows const propagation to potentially resolve the length before type
checking is performed again.
Composite types are considered equal if their names and resolved program names match. If either side still has const generic arguments, they are treated as equal unconditionally since monomorphization and other passes of type-checking will handle mismatches later.
Sourcepub fn eq_flat_relaxed(&self, other: &Self) -> bool
pub fn eq_flat_relaxed(&self, other: &Self) -> bool
Returns true if the self Type is equal to the other Type in all aspects besides composite program of origin.
In the case of futures, it also makes sure that if both are not explicit, they are equal.
Flattens array syntax: [[u8; 1]; 2] == [u8; (2, 1)] == true
Composite types are considered equal if their names match. If either side still has const generic arguments, they are treated as equal unconditionally since monomorphization and other passes of type-checking will handle mismatches later.
pub fn from_snarkvm<N: Network>( t: &PlaintextType<N>, program_id: ProgramId, ) -> Self
pub fn to_snarkvm<N: Network>(&self) -> Result<PlaintextType<N>>
pub fn size_in_bits<N: Network, F0, F1>(
&self,
is_raw: bool,
get_structs: F0,
get_external_structs: F1,
) -> Result<usize>where
F0: Fn(&Identifier<N>) -> Result<StructType<N>>,
F1: Fn(&Locator<N>) -> Result<StructType<N>>,
Sourcepub fn can_coerce_to(&self, expected: &Type) -> bool
pub fn can_coerce_to(&self, expected: &Type) -> bool
Determines whether self can be coerced to the expected type.
This method checks if the current type can be implicitly coerced to the expected type according to specific rules:
Optional<T>can be coerced toOptional<T>.Tcan be coerced toOptional<T>.- Arrays
[T; N]can be coerced to[Optional<T>; N]if lengths match or are unknown, and element types are coercible. - Falls back to an equality check for other types.
Arguments
expected- The type to whichselfis being coerced.
Returns
true if coercion is allowed; false otherwise.
pub fn is_optional(&self) -> bool
pub fn is_vector(&self) -> bool
pub fn is_mapping(&self) -> bool
pub fn to_optional(&self) -> Type
pub fn is_empty(&self) -> bool