pub struct StructExpression {
pub name: Identifier,
pub members: Vec<StructVariableInitializer>,
pub span: Span,
pub id: NodeID,
}Expand description
A struct initialization expression, e.g., Foo { bar: 42, baz }.
Fields
name: IdentifierThe name of the structure type to initialize.
members: Vec<StructVariableInitializer>Initializer expressions for each of the fields in the struct.
N.B. Any functions or member constants in the struct definition are excluded from this list.
span: SpanA span from name to }.
id: NodeIDThe ID of the node.
Implementations
Sourceimpl StructExpression
impl StructExpression
Sourcepub fn check_record(&self) -> bool
pub fn check_record(&self) -> bool
Returns true if the record has all required fields and visibility.
Sourcepub fn to_record_string(&self) -> String
pub fn to_record_string(&self) -> String
Returns the struct as a record interface with visibility.