pub struct FunctionInput {
    pub identifier: Identifier,
    pub mode: Mode,
    pub type_: Type,
    pub span: Span,
}
A function parameter.

Fields

identifier: Identifier

The name the parameter is accessible as in the function’s body.

mode: Mode

The mode of the function parameter.

type_: Type

What’s the parameter’s type?

span: Span

The parameters span from any annotations to its type.