pub struct ConditionalStatement {
    pub condition: Expression,
    pub then: Block,
    pub otherwise: Option<Box<Statement>>,
    pub span: Span,
    pub id: NodeID,
}
An if condition block (else next)? statement.

Fields

condition: Expression

The bool-typed condition deciding what to evaluate.

then: Block

The block to evaluate in case condition yields true.

otherwise: Option<Box<Statement>>

The statement, if any, to evaluate when condition yields false.

span: Span

The span from if to next or to block.

id: NodeID

The ID of the node.