pub struct BinaryExpression {
pub left: Expression,
pub right: Expression,
pub op: BinaryOperation,
pub span: Span,
pub id: NodeID,
}Expand description
A binary expression left op right of two operands separated by some operator.
For example, foo + bar.
Fields
left: ExpressionThe left operand of the expression.
right: ExpressionThe right operand of the expression.
op: BinaryOperationThe operand defining the meaning of the resulting binary expression.
span: SpanThe span from left to right.
id: NodeIDThe ID of the expression.