pub struct CallExpression {
pub function: Path,
pub const_arguments: Vec<Expression>,
pub arguments: Vec<Expression>,
pub span: Span,
pub id: NodeID,
}Expand description
A function call expression, e.g.foo(args) or Foo::bar(args).
Fields
function: PathA path to a callable function, either a member of a composite or a free function.
const_arguments: Vec<Expression>Expressions for the const arguments passed to the function’s const parameters.
arguments: Vec<Expression>Expressions for the arguments passed to the function’s parameters.
span: SpanSpan of the entire call function(arguments).
id: NodeIDThe ID of the node.