pub struct Composite {
pub identifier: Identifier,
pub const_parameters: Vec<ConstParameter>,
pub members: Vec<Member>,
pub is_record: bool,
pub span: Span,
pub id: NodeID,
}Expand description
A composite type definition, e.g., struct Foo { my_field: Bar } and record Token { owner: address, amount: u64}.
Type identity is decided by the full path including identifier,
as the record is nominal, not structural.
The fields are named so struct Foo(u8, u16) is not allowed.
Fields
identifier: IdentifierThe name of the type in the type system in this module.
const_parameters: Vec<ConstParameter>The composite’s const parameters.
members: Vec<Member>The fields, constant variables, and functions of this composite.
is_record: boolWas this a record Foo { ... }?
If so, it wasn’t a composite.
span: SpanThe entire span of the composite definition.
id: NodeIDThe ID of the node.
Implementations
Sourceimpl Composite
impl Composite
pub fn from_external_record<N: Network>( input: &RecordType<N>, program_id: ProgramId, ) -> Self
pub fn from_snarkvm<N: Network>( input: &StructType<N>, program: ProgramId, ) -> Self