pub struct CompositeExpression {
pub path: Path,
pub const_arguments: Vec<Expression>,
pub members: Vec<CompositeFieldInitializer>,
pub span: Span,
pub id: NodeID,
}Expand description
A composite initialization expression, e.g., Foo { bar: 42, baz }.
Fields
path: PathA path to a composite type to initialize.
const_arguments: Vec<Expression>Expressions for the const arguments passed to the composite’s const parameters.
members: Vec<CompositeFieldInitializer>Initializer expressions for each of the fields in the composite.
N.B. Any functions or member constants in the composite definition are excluded from this list.
span: SpanA span from name to }.
id: NodeIDThe ID of the node.