pub struct CompositeType {
pub path: Path,
pub const_arguments: Vec<Expression>,
}Expand description
A composite type of a identifier and external program name.
Fields
path: PathThe path to the composite definition.
const_arguments: Vec<Expression>Expressions for the const arguments passed to the composite’s const parameters.