pub struct Function {
pub annotations: Vec<Annotation>,
pub variant: Variant,
pub identifier: Identifier,
pub const_parameters: Vec<ConstParameter>,
pub input: Vec<Input>,
pub output: Vec<Output>,
pub output_type: Type,
pub block: Block,
pub span: Span,
pub id: NodeID,
}Expand description
A function definition.
Fields
annotations: Vec<Annotation>Annotations on the function.
variant: VariantIs this function a transition, inlined, or a regular function?.
identifier: IdentifierThe function identifier, e.g., foo in function foo(...) { ... }.
const_parameters: Vec<ConstParameter>The function’s const parameters.
input: Vec<Input>The function’s input parameters.
output: Vec<Output>The function’s output declarations.
output_type: TypeThe function’s output type.
block: BlockThe body of the function.
span: SpanThe entire span of the function definition.
id: NodeIDThe ID of the node.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn new(
annotations: Vec<Annotation>,
variant: Variant,
identifier: Identifier,
const_parameters: Vec<ConstParameter>,
input: Vec<Input>,
output: Vec<Output>,
block: Block,
span: Span,
id: NodeID,
) -> Self
pub fn new( annotations: Vec<Annotation>, variant: Variant, identifier: Identifier, const_parameters: Vec<ConstParameter>, input: Vec<Input>, output: Vec<Output>, block: Block, span: Span, id: NodeID, ) -> Self
Initialize a new function.
Sourcepub fn has_final_output(&self) -> bool
pub fn has_final_output(&self) -> bool
Returns true if any output of the function is a Final