pub struct Library {
pub name: Symbol,
pub modules: IndexMap<Vec<Symbol>, Module>,
pub consts: Vec<(Symbol, ConstDeclaration)>,
pub structs: Vec<(Symbol, Composite)>,
pub functions: Vec<(Symbol, Function)>,
}Expand description
Stores the Leo library abstract syntax tree.
Libraries may contain const declarations, struct definitions, fn functions,
and submodules (each a separate source file under the library’s src/ directory).
Fields
name: Symbolmodules: IndexMap<Vec<Symbol>, Module>Submodules of this library, keyed by their path (e.g., [utils] for src/utils.leo).
consts: Vec<(Symbol, ConstDeclaration)>The constants defined in this library.
structs: Vec<(Symbol, Composite)>The struct definitions in this library.
functions: Vec<(Symbol, Function)>The function definitions in this library.