pub struct MappingType {
pub key: Box<Type>,
pub value: Box<Type>,
}Expand description
A mapping type of a key and value type.
Fields
key: Box<Type>value: Box<Type>Trait Implementations
Sourceimpl Clone for MappingType
impl Clone for MappingType
Sourcefn clone(&self) -> MappingType
fn clone(&self) -> MappingType
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MappingType
impl Debug for MappingType
Sourceimpl<'de> Deserialize<'de> for MappingType
impl<'de> Deserialize<'de> for MappingType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for MappingType
impl Display for MappingType
Sourceimpl PartialEq for MappingType
impl PartialEq for MappingType
Sourcefn eq(&self, other: &MappingType) -> bool
fn eq(&self, other: &MappingType) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MappingType
impl Serialize for MappingType
impl Eq for MappingType
impl StructuralPartialEq for MappingType