pub struct Program {
pub modules: IndexMap<Vec<Symbol>, Module>,
pub imports: IndexMap<Symbol, ProgramId>,
pub stubs: IndexMap<Symbol, Stub>,
pub program_scopes: IndexMap<Symbol, ProgramScope>,
}Expand description
Stores the Leo program abstract syntax tree.
Fields
modules: IndexMap<Vec<Symbol>, Module>A map from module paths to module definitions.
imports: IndexMap<Symbol, ProgramId>A map from import names (including the .aleo if present) to import definitions.
stubs: IndexMap<Symbol, Stub>A map from program stub names to program stub scopes.
program_scopes: IndexMap<Symbol, ProgramScope>A map from program names to program scopes.
Implementations
Sourceimpl Program
impl Program
Sourcepub fn to_json_string(&self) -> Result<String>
pub fn to_json_string(&self) -> Result<String>
Serializes the ast into a JSON string.
pub fn to_json_value(&self) -> Result<Value>
Sourcepub fn to_json_file(&self, path: PathBuf, file_name: &str) -> Result<()>
pub fn to_json_file(&self, path: PathBuf, file_name: &str) -> Result<()>
Serializes the ast into a JSON file.
Sourcepub fn to_json_file_without_keys(
&self,
path: PathBuf,
file_name: &str,
excluded_keys: &[&str],
) -> Result<()>
pub fn to_json_file_without_keys( &self, path: PathBuf, file_name: &str, excluded_keys: &[&str], ) -> Result<()>
Serializes the ast into a JSON value and removes keys from object mappings before writing to a file.
Sourcepub fn from_json_string(json: &str) -> Result<Self>
pub fn from_json_string(json: &str) -> Result<Self>
Deserializes the JSON string into a ast.
Sourcepub fn from_json_file(path: PathBuf) -> Result<Self>
pub fn from_json_file(path: PathBuf) -> Result<Self>
Deserializes the JSON string into a ast from a file.