pub struct TernaryExpression {
pub condition: Expression,
pub if_true: Expression,
pub if_false: Expression,
pub span: Span,
pub id: NodeID,
}Expand description
A ternary conditional expression, that is, condition ? if_true : if_false.
Fields
condition: ExpressionThe condition determining which branch to pick.
if_true: ExpressionThe branch the expression evaluates to if condition evaluates to true.
if_false: ExpressionThe branch the expression evaluates to if condition evaluates to false.
span: SpanThe span from condition to if_false.
id: NodeIDThe ID of the node.