pub struct Struct {
pub identifier: Identifier,
pub members: Vec<Member>,
pub is_record: bool,
pub span: Span,
pub id: NodeID,
}Expand description
A struct type definition, e.g., struct Foo { my_field: Bar }.
In some languages these are called structs.
Type identity is decided by the full path including struct_name,
as the record is nominal, not structural.
The fields are named so struct Foo(u8, u16) is not allowed.
Fields
identifier: IdentifierThe name of the type in the type system in this module.
members: Vec<Member>The fields, constant variables, and functions of this structure.
is_record: boolWas this a record Foo { ... }?
If so, it wasn’t a struct.
span: SpanThe entire span of the struct definition.
id: NodeIDThe ID of the node.
Implementations