Struct leo_ast::access::AssociatedFunction
source · pub struct AssociatedFunction {
pub ty: Type,
pub name: Identifier,
pub arguments: Vec<Expression>,
pub span: Span,
}Expand description
An access expression to an associated function in a struct, e.g.Pedersen64::hash().
Fields
ty: TypeThe inner struct type.
name: IdentifierThe static struct member function that is being accessed.
arguments: Vec<Expression>The arguments passed to the function name.
span: SpanThe span for the entire expression Foo::bar().