pub struct Path {
pub span: Span,
pub id: NodeID,
/* private fields */
}Expand description
A Path in a program.
Fields
span: SpanA span locating where the path occurred in the source.
id: NodeIDThe ID of the node.
Implementations
Sourceimpl Path
impl Path
Sourcepub fn new(
user_program: Option<Identifier>,
qualifier: Vec<Identifier>,
identifier: Identifier,
span: Span,
id: NodeID,
) -> Self
pub fn new( user_program: Option<Identifier>, qualifier: Vec<Identifier>, identifier: Identifier, span: Span, id: NodeID, ) -> Self
Creates a new unresolved Path from the given components.
user_program: An optional program name (e.g.creditsincredits.aleo/Bar)qualifier: The namespace segments (e.g.,foo::barinfoo::bar::baz).identifier: The final item in the path (e.g.,baz).span: The source code span for this path.id: The node ID.
Sourcepub fn identifier(&self) -> &Identifier
pub fn identifier(&self) -> &Identifier
Returns the final identifier of the path (e.g., baz in foo::bar::baz).
Sourcepub fn qualifier(&self) -> &[Identifier]
pub fn qualifier(&self) -> &[Identifier]
Returns a slice of the qualifier segments (e.g., [foo, bar] in foo::bar::baz).
Sourcepub fn segments_iter(&self) -> impl Iterator<Item = Symbol> + '_
pub fn segments_iter(&self) -> impl Iterator<Item = Symbol> + '_
Returns an iterator over all segments as Symbols (qualifiers + identifier).
Sourcepub fn user_program(&self) -> Option<&Identifier>
pub fn user_program(&self) -> Option<&Identifier>
Returns the optional program identifier.
Sourcepub fn with_user_program(self, user_program: Identifier) -> Self
pub fn with_user_program(self, user_program: Identifier) -> Self
Returns self after setting it user_program field to user_program.
pub fn span(&self) -> Span
pub fn id(&self) -> NodeID
pub fn is_resolved(&self) -> bool
pub fn is_local(&self) -> bool
pub fn is_global(&self) -> bool
Sourcepub fn program(&self) -> Option<Symbol>
pub fn program(&self) -> Option<Symbol>
Returns the program symbol this path refers to, if known.
Priority:
- User-written program qualifier (e.g.
foo.aleo/bar::baz) - Resolved global target program
- None (unresolved or local)
Sourcepub fn try_local_symbol(&self) -> Option<Symbol>
pub fn try_local_symbol(&self) -> Option<Symbol>
Returns the Symbol if local, None if not.
Sourcepub fn try_global_location(&self) -> Option<&Location>
pub fn try_global_location(&self) -> Option<&Location>
Returns the Location if global, None if not.
Sourcepub fn expect_local_symbol(&self) -> Symbol
pub fn expect_local_symbol(&self) -> Symbol
Returns the Symbol if local, panics if not.
Sourcepub fn expect_global_location(&self) -> &Location
pub fn expect_global_location(&self) -> &Location
Returns the Location if global, panics if not.
Sourcepub fn with_updated_last_symbol(self, new_symbol: Symbol) -> Self
pub fn with_updated_last_symbol(self, new_symbol: Symbol) -> Self
Returns a new Path with the final identifier replaced by new_symbol.
This updates:
identifier.nametarget:Local(_)→Local(new_symbol)Global(Location)→ same location, but with the final path segment replacedUnresolved→ unchanged
Sourcepub fn resolve_as_global_in_module<I>(
self,
program: Symbol,
current_module: I,
) -> Selfwhere
I: IntoIterator<Item = Symbol>,
pub fn resolve_as_global_in_module<I>(
self,
program: Symbol,
current_module: I,
) -> Selfwhere
I: IntoIterator<Item = Symbol>,
Resolves this path as a global path using the current module context.
This method constructs an absolute global Location by combining:
- the current module path,
- any user-written qualifier segments, and
- the final identifier.
The resolution only affects the target field and preserves
the original user-written syntax of the path.