Struct leo_ast::functions::input::FunctionInput
source · pub struct FunctionInput {
pub identifier: Identifier,
pub mode: Mode,
pub type_: Type,
pub span: Span,
}Expand description
A function parameter.
Fields
identifier: IdentifierThe name the parameter is accessible as in the function’s body.
mode: ModeThe mode of the function parameter.
type_: TypeWhat’s the parameter’s type?
span: SpanThe parameters span from any annotations to its type.