Struct leo_ast::statement::conditional::ConditionalStatement
source · pub struct ConditionalStatement {
pub condition: Expression,
pub then: Block,
pub otherwise: Option<Box<Statement>>,
pub span: Span,
}Expand description
An if condition block (else next)? statement.
Fields
condition: ExpressionThe bool-typed condition deciding what to evaluate.
then: BlockThe block to evaluate in case condition yields true.
otherwise: Option<Box<Statement>>The statement, if any, to evaluate when condition yields false.
span: SpanThe span from if to next or to block.